@@ -57,8 +57,26 @@ def youtube_dl_id(file) -> str:
     return utils.conform([*yt_ids[0]])[0]
 
 
+def get_text_files(path, OCR=False, speech_recognition=False):
+    TEXTRACT_EXTENSIONS = "csv|tab|tsv|doc|docx|eml|epub|json|htm|html|msg|odt|pdf|pptx|ps|rtf|txt|log|xlsx|xls"
+    if OCR:
+        ocr_only = "|gif|jpg|jpeg|png|tif|tff|tiff"
+        TEXTRACT_EXTENSIONS += ocr_only
+    if speech_recognition:
+        speech_recognition_only = "|mp3|ogg|wav"
+        TEXTRACT_EXTENSIONS += speech_recognition_only
+
+    TEXTRACT_EXTENSIONS = TEXTRACT_EXTENSIONS.split("|")
+    text_files = []
+    for f in Path(path).resolve().rglob("*"):
+        if f.is_file() and (f.suffix[1:].lower() in TEXTRACT_EXTENSIONS):
+            text_files.append(str(f))
+
+    return text_files
+
+
 def get_media_files(path, audio=False):
-    FFMPEG_DEMUXERS = (
+    FFMPEG_EXTENSIONS = (
         "str|aa|aax|acm|adf|adp|dtk|ads|ss2|adx|aea|afc|aix|al|apl"
         "|mac|aptx|aptxhd|aqt|ast|obu|avi|avr|avs|avs2|avs3|bfstm|bcstm|binka"
         "|bit|bmv|brstm|cdg|cdxl|xl|c2|302|daud|str|adp|dav|dss|dts|dtshd|dv"
@@ -79,15 +97,37 @@ def get_media_files(path, audio=False):
     )
     if audio:
         audio_only = "|opus|oga|ogg|mp3|m2a|m4a|flac|wav|wma|aac|aa3|ac3|ape"
-        FFMPEG_DEMUXERS += audio_only
+        FFMPEG_EXTENSIONS += audio_only
 
-    FFMPEG_ENDINGS = FFMPEG_DEMUXERS.split("|")
-    video_files = []
+    FFMPEG_EXTENSIONS = FFMPEG_EXTENSIONS.split("|")
+    media_files = []
     for f in Path(path).resolve().rglob("*"):
-        if f.is_file() and (f.suffix[1:].lower() in FFMPEG_ENDINGS):
-            video_files.append(str(f))
+        if f.is_file() and (f.suffix[1:].lower() in FFMPEG_EXTENSIONS):
+            media_files.append(str(f))
 
-    return video_files
+    return media_files
+
+
+def get_image_files(path):
+    IMAGE_EXTENSIONS = (
+        "pdf|ai|ait|png|jng|mng|arq|arw|cr2|cs1|dcp|dng|eps|epsf|ps|erf|exv|fff"
+        "|gpr|hdp|wdp|jxr|iiq|insp|jpeg|jpg|jpe|mef|mie|mos|mpo|mrw|nef|nrw|orf"
+        "|ori|pef|psd|psb|psdt|raf|raw|rw2|rwl|sr2|srw|thm|tiff|tif|x3f|flif|gif"
+        "|icc|icm|avif|heic|heif|hif|jp2|jpf|jpm|jpx|j2c|j2k|jpc|3fr|btf|dcr|k25"
+        "|kdc|miff|mif|rwz|srf|xcf|bpg|doc|dot|fla|fpx|max|ppt|pps|pot|vsd|xls"
+        "|xlt|pict|pct|360|3g2|3gp2|3gp|3gpp|aax|dvb|f4a|f4b|f4p|f4v|lrv|m4b"
+        "|m4p|m4v|mov|qt|mqv|qtif|qti|qif|cr3|crm|jxl|crw|ciff|ind|indd|indt"
+        "|nksc|vrd|xmp|la|ofr|pac|riff|rif|wav|webp|wv|asf|divx|djvu|djv|dvr-ms"
+        "|flv|insv|inx|swf|wma|wmv|exif|eip|psp|pspimage"
+    )
+
+    IMAGE_EXTENSIONS = IMAGE_EXTENSIONS.split("|")
+    image_files = []
+    for f in Path(path).resolve().rglob("*"):
+        if f.is_file() and (f.suffix[1:].lower() in IMAGE_EXTENSIONS):
+            image_files.append(str(f))
+
+    return image_files
 
 
 def is_mounted(paths, mount_point):
