@@ -1,4 +1,4 @@
-import csv, operator, os, platform, re, shutil, socket, subprocess
+import csv, math, operator, os, platform, re, shutil, socket, subprocess
 from copy import deepcopy
 from io import StringIO
 from pathlib import Path
@@ -407,13 +407,6 @@ def socket_play(args, m):
     sleep(args.interdimensional_cable)
 
 
-def is_odd(x):
-    if x & 1:
-        return True
-    else:
-        return False
-
-
 def geom(x_size, y_size, x, y):
     return [f"--geometry={x_size}%x{y_size}%+{x}%+{y}%"]
 
@@ -454,15 +447,22 @@ def vstack(display, qty):
         28: geom_walk(v=4, h=7),
         30: geom_walk(v=5, h=6),
         32: geom_walk(v=4, h=8),
-        33: geom_walk(v=3, h=11),
+        36: geom_walk(v=6, h=6),
+        49: geom_walk(v=7, h=7),
+        64: geom_walk(v=8, h=8),
+        81: geom_walk(v=9, h=9),
+        100: geom_walk(v=10, h=10),
     }
     if qty in mapper.keys():
         holes = mapper[qty]
-    elif is_odd(qty):
-        holes = geom_walk(v=qty)
     else:
-        v, h = divmod(qty, 2)
-        holes = geom_walk(v=v, h=v + h)
+        dv = list(utils.divisor_gen(qty))
+        if not dv:
+            holes = geom_walk(v=qty)
+        else:
+            v = dv[len(dv) // 2]
+            h = qty // v
+            holes = geom_walk(v=v, h=h)
 
     return [[f'--screen-name="{display.name}"', *hole] for hole in holes]
 
@@ -489,15 +489,22 @@ def hstack(display, qty):
         28: geom_walk(v=7, h=4),
         30: geom_walk(v=6, h=5),
         32: geom_walk(v=8, h=4),
-        33: geom_walk(v=11, h=3),
+        36: geom_walk(v=6, h=6),
+        49: geom_walk(v=7, h=7),
+        64: geom_walk(v=8, h=8),
+        81: geom_walk(v=9, h=9),
+        100: geom_walk(v=10, h=10),
     }
     if qty in mapper.keys():
         holes = mapper[qty]
-    elif is_odd(qty):
-        holes = geom_walk(h=qty)
     else:
-        h, v = divmod(qty, 2)
-        holes = geom_walk(h=h, v=h + v)
+        dv = list(utils.divisor_gen(qty))
+        if not dv:
+            holes = geom_walk(h=qty)
+        else:
+            h = dv[len(dv) // 2]
+            v = qty // h
+            holes = geom_walk(v=v, h=h)
 
     return [[f'--screen-name="{display.name}"', *hole] for hole in holes]
 
@@ -511,6 +518,17 @@ def get_display_by_name(displays, screen_name):
     raise Exception(f'Display "{screen_name}" not found. I see: "{display_names}"')
 
 
+def which_stack(args, display):
+    if args.hstack or args.portrait:
+        return hstack
+    elif args.vstack:
+        return vstack
+    elif display.width > display.height:
+        return vstack
+    else:  # tall or square: prefer horizontal split
+        return hstack
+
+
 def get_multiple_player_template(args):
     displays = get_monitors()
     if args.screen_name:
@@ -534,10 +552,8 @@ def get_multiple_player_template(args):
         if remainder > 0 and (d_idx + 1) == len(displays):
             qty += remainder
 
-        if display.width > display.height:  # wide
-            players.extend(vstack(display, qty))
-        else:  # tall or square: prefer horizontal split
-            players.extend(hstack(display, qty))
+        fn_stack = which_stack(args, display)
+        players.extend(fn_stack(display, qty))
 
     log.debug(players)
 
@@ -581,7 +597,7 @@ def multiple_player(args, media):
                         players[t_idx] = {**m, "process": open_player(t, m)}
 
             log.debug("-- A dragon slumbers over its hoard of %s media --", len(media))
-            sleep(0.5)  # stagger like Sir Michael Philip Jagger
+            sleep(0.2)
     finally:
         for m in players:
             m["process"].kill()
