@@ -288,6 +288,17 @@ def compile_query(query, *args):
     return query
 
 
+def divisor_gen(n):
+    large_divisors = []
+    for i in range(2, int(math.sqrt(n) + 1)):
+        if n % i == 0:
+            yield i
+            if i * i != n:
+                large_divisors.append(n / i)
+    for divisor in reversed(large_divisors):
+        yield int(divisor)
+
+
 _RE_COMBINE_WHITESPACE = re.compile(r"\s+")
 
 
